@@ -87,6 +87,30 @@ def load_dataset(path_data_file: str,
                    form_rep_type=form_rep_type)
 
 
+def get_pristine_form(form):
+    """
+    Return a chemical formula of the pristine material of the given ``form``.
+
+    :param form: (*str*) A chemical formula of the material.
+    :return: (*str*) A chemical formula of the pristine material.
+    """
+
+    form_dict = parse_formula(form)
+    pristine_mat = dict()
+
+    sorted_keys = sorted(form_dict.keys(), key=lambda x: x.lower())
+    for e in sorted_keys:
+        if form_dict[e] >= 0.5:
+            pristine_mat[e] = round(form_dict[e])
+
+    form_pristine_mat = ''
+    for e in pristine_mat:
+        if pristine_mat[e] > 0:
+            form_pristine_mat += e + str(pristine_mat[e])
+
+    return form_pristine_mat
+
+
 def __get_compact_form_vec(form: str,
                            elem_attrs: torch.Tensor) -> torch.Tensor:
     """
@@ -126,8 +150,8 @@ def __get_compact_form_vec(form: str,
     # Generate a feature vector of the formula based on the weighted sum, std., and max. of the atomic features.
     form_vec = torch.hstack([wt_sum_feats,
                              torch.std(form_atom_feats, dim=0),
-                             torch.min(form_atom_feats, dim=0)[0],
-                             torch.max(form_atom_feats, dim=0)[0]])
+                             torch.max(form_atom_feats, dim=0)[0],
+                             torch.min(form_atom_feats, dim=0)[0]])
 
     return form_vec
 
